import ch.ntb.usb.Device;
import ch.ntb.usb.LibusbJava;
import ch.ntb.usb.USB;
import ch.ntb.usb.USBException;
import ch.ntb.usb.Usb_Bus;
import ch.ntb.usb.Usb_Device;
import ch.ntb.usb.Usb_Device_Descriptor;


public class USBTiny45 {
	static short		vendorId = (short)0x1384;
	static short		productId = (short)0x8888;
	static int			USB_ENDPOINT_IN = 0x80;
	
	static long usbOpenDevice(short idvendor, short idproduct) throws USBException {
		Usb_Device	dev = null;
		Usb_Bus		bus = USB.getBus();
		long		usbHandle = 0L;
		while (bus != null) {
			dev = bus.getDevices();
			while (dev != null) {	
				usbHandle = LibusbJava.usb_open(dev);
				if (usbHandle != 0) {
					Usb_Device_Descriptor devDesc = dev.getDescriptor();
					String retp = LibusbJava.usb_get_string_simple(usbHandle, (int)devDesc.getIProduct());
					String retm = LibusbJava.usb_get_string_simple(usbHandle, (int)devDesc.getIManufacturer());
					if (retp != null && retm != null) {
						if (devDesc.getIdVendor() == idvendor
								&& devDesc.getIdProduct() == idproduct) {
							return usbHandle;
						}											
					}
				}
				dev = dev.getNext();
			}
			bus = bus.getNext();
		}
		LibusbJava.usb_close(usbHandle);
		return 0L;		
	}

	static private void testUsbOpenDevice() throws Exception {
		byte[]	buffer = new byte[2312];
		int		i=3, j=4, k=5, l=6, m=7, n=8, o=9;
		int		ret;

		long devHandle = usbOpenDevice(vendorId, productId);
		if (devHandle == 0) {
			System.err.println("usbOpenDevice failed\n");
			return;
		}
		ret = LibusbJava.usb_control_msg(devHandle,
				USB.REQ_TYPE_TYPE_VENDOR|USB.REQ_TYPE_RECIP_DEVICE
				|USB_ENDPOINT_IN, 
				i, j+256*k, l+256*m, buffer, n+256*o, 5000);
		System.out.format("ret=%d \n", ret);
		for (int p=0; p < ret; p++) {
			System.out.format("buffer[%d]=%d \n", p, buffer[p]);
		}
		LibusbJava.usb_close(devHandle);		
	}

	static private void testDeviceAndUSB() throws Exception {
		byte[]	buffer = new byte[2312];
		int		i=3, j=4, k=5, l=6, m=7, n=8, o=9;
		int		ret;

		Device device = USB.getDevice(vendorId, productId);
		if (device == null) {
			System.err.println("usbOpenDevice failed\n");
			return;
		}
		device.open(1, 0, -1);
		ret = device.controlMsg(
				USB.REQ_TYPE_TYPE_VENDOR|USB.REQ_TYPE_RECIP_DEVICE
				|USB_ENDPOINT_IN, 
				i, j+256*k, l+256*m, buffer, n+256*o, 5000, false);
		System.out.format("ret=%d \n", ret);
		for (int p=0; p < ret; p++) {
			System.out.format("buffer[%d]=%d \n", p, buffer[p]);
		}
		device.close();
		
	}
	
	public static void main(String[] args) {		
		try {
//			testDeviceAndUSB();
			testUsbOpenDevice();
		}
		catch (Exception e) {
			e.printStackTrace();
		}
	}
}
